@@ -603,10 +603,9 @@ class BaseTransferPalette(Palette):
     def _format_size(self, size):
         if size < 1024:
             return _('%d B') % size
-        elif size < 1048576:
+        if size < 1048576:
             return _('%d KiB') % (size / 1024)
-        else:
-            return _('%d MiB') % (size / 1048576)
+        return _('%d MiB') % (size / 1048576)
 
     def update_progress(self):
         logging.debug('update_progress: %r',
