@@ -28,7 +28,7 @@ from sugar3.graphics import style
 from sugar3.graphics.xocolor import XoColor
 from sugar3.graphics.icon import CanvasIcon, get_icon_file_name
 from sugar3.graphics.icon import Icon, CellRendererIcon
-from sugar3.graphics.alert import Alert
+from sugar3.graphics.alert import Alert, ConfirmationAlert
 from sugar3.util import format_size
 from sugar3.graphics.objectchooser import get_preview_pixbuf
 from sugar3.activity.activity import PREVIEW_SIZE
@@ -264,7 +264,7 @@ class ExpandedEntry(Gtk.EventBox, BaseExpandedEntry):
         self._keep_sid = self._keep_icon.connect(
             'toggled', self._keep_icon_toggled_cb)
         self._title.connect(
-            'focus-out-event', self._title_focus_out_event_cb)
+            'changed', self._title_changed_event_cb)
 
         if Gtk.Widget.get_default_direction() == Gtk.TextDirection.RTL:
             # Reverse header children.
@@ -496,8 +496,34 @@ class ExpandedEntry(Gtk.EventBox, BaseExpandedEntry):
                 GLib.timeout_add_seconds(1,
                                          self._update_title_cb)
 
-    def _title_focus_out_event_cb(self, entry, event):
-        self._update_entry()
+    def _title_changed_event_cb(self, widget):
+        old_title = self._metadata.get('title', None)
+        new_title = self._title.get_text()
+        if old_title != new_title:
+            if new_title == '' or new_title.isspace():
+                alert = ConfirmationAlert()
+                alert.props.title = _('Empty title')
+                alert.props.msg = _('The title is usually not left empty')
+                alert.connect(
+                    'response',
+                    self._title_alert_response_cb,
+                    old_title,
+                    self._metadata.get('title_set_by_user', 0)
+                )
+                journalwindow.get_journal_window().add_alert(alert)
+                alert.show()
+
+            self._update_entry()
+
+    def _title_alert_response_cb(self, alert, response_id, old_title, old_title_set_by_user):
+        journalwindow.get_journal_window().remove_alert(alert)
+
+        if response_id is Gtk.ResponseType.CANCEL:
+            self._title.set_text(old_title)
+            self._icon.palette.props.primary_text = old_title
+            self._metadata['title'] = old_title
+            self._metadata['title_set_by_user'] = old_title_set_by_user
+            self._update_entry(needs_update=True)
 
     def _description_tags_focus_out_event_cb(self, text_view, event):
         self._update_entry()
@@ -518,6 +544,7 @@ class ExpandedEntry(Gtk.EventBox, BaseExpandedEntry):
             self._metadata['title_set_by_user'] = '1'
             needs_update = True
 
+
         bounds = self._tags.get_buffer().get_bounds()
         old_tags = self._metadata.get('tags', None)
         new_tags = self._tags.get_buffer().get_text(bounds[0], bounds[1],
