@@ -40,6 +40,7 @@ from jarabe.journal.journaltoolbox import EditToolbox
 from jarabe.journal.projectview import ProjectView
 
 from jarabe.journal.listview import ListView
+from jarabe.journal.listmodel import ListModel
 from jarabe.journal.detailview import DetailView
 from jarabe.journal.volumestoolbar import VolumesToolbar
 from jarabe.journal import misc
@@ -95,8 +96,7 @@ class JournalActivityDBusService(dbus.service.Object):
         bundle = get_bundle(bundle_id, object_id)
         if bundle is None:
             return ''
-        else:
-            return bundle.get_path()
+        return bundle.get_path()
 
     @dbus.service.method(J_DBUS_INTERFACE, in_signature='ss',
                          out_signature='b')
@@ -450,8 +450,10 @@ class JournalActivity(JournalWindow):
     def __title_edit_started_cb(self, list_view):
         self.disconnect_by_func(self.__key_press_event_cb)
 
-    def __title_edit_finished_cb(self, list_view):
-        self.connect('key-press-event', self.__key_press_event_cb)
+    def __title_edit_finished_cb(self, list_view, new_text, path):
+        list_view_model = list_view.get_model()
+        iterator = list_view_model.get_iter(path)
+        list_view_model[iterator][ListModel.COLUMN_TITLE] = new_text
 
     def show_main_view(self):
         self._active_view = JournalViews.MAIN
@@ -493,9 +495,8 @@ class JournalActivity(JournalWindow):
         metadata = model.get(object_id)
         if metadata is None:
             return False
-        else:
-            self._show_secondary_view(object_id)
-            return True
+        self._show_secondary_view(object_id)
+        return True
 
     def __volume_changed_cb(self, volume_toolbar, mount_point):
         logging.debug('Selected volume: %r.', mount_point)
